summaryrefslogtreecommitdiffstats
path: root/kmix/viewapplet.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-18 18:33:07 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-18 18:33:07 -0600
commit3c299dfe48c0060272c2966fff599b3b417e2ee4 (patch)
treef248b71f55539d6689a4cbe086d5d8cc146c8998 /kmix/viewapplet.cpp
parentf59dfa08651a47f21d004e8e4cb5020b8035287e (diff)
downloadtdemultimedia-3c299dfe48c0060272c2966fff599b3b417e2ee4.tar.gz
tdemultimedia-3c299dfe48c0060272c2966fff599b3b417e2ee4.zip
Rename old tq methods that no longer need a unique name
Diffstat (limited to 'kmix/viewapplet.cpp')
-rw-r--r--kmix/viewapplet.cpp12
1 files changed, 6 insertions, 6 deletions
diff --git a/kmix/viewapplet.cpp b/kmix/viewapplet.cpp
index 6b25dde0..cf2b15b6 100644
--- a/kmix/viewapplet.cpp
+++ b/kmix/viewapplet.cpp
@@ -56,11 +56,11 @@ ViewApplet::ViewApplet(TQWidget* parent, const char* name, Mixer* mixer, ViewBas
if ( _viewOrientation == Qt::Horizontal ) {
_layoutMDW = new TQHBoxLayout( this );
- tqsetSizePolicy(TQSizePolicy::Fixed, TQSizePolicy::Preferred);
+ setSizePolicy(TQSizePolicy::Fixed, TQSizePolicy::Preferred);
}
else {
_layoutMDW = new TQVBoxLayout( this );
- tqsetSizePolicy(TQSizePolicy::Preferred, TQSizePolicy::Fixed);
+ setSizePolicy(TQSizePolicy::Preferred, TQSizePolicy::Fixed);
}
@@ -139,10 +139,10 @@ void ViewApplet::constructionFinished() {
}
-TQSize ViewApplet::tqsizeHint() const {
+TQSize ViewApplet::sizeHint() const {
// Basically out main tqlayout knows very good what the sizes should be
- TQSize qsz = _layoutMDW->tqsizeHint();
- //kdDebug(67100) << "ViewApplet::tqsizeHint(): NewSize is " << qsz << "\n";
+ TQSize qsz = _layoutMDW->sizeHint();
+ //kdDebug(67100) << "ViewApplet::sizeHint(): NewSize is " << qsz << "\n";
return qsz;
}
@@ -196,7 +196,7 @@ void ViewApplet::resizeEvent(TQResizeEvent *qre)
// kdDebug(67100) << "ViewApplet::resizeEvent(). SHOULD resize _layoutMDW to " << qre->size() << endl;
//TQWidget::resizeEvent(qre);
// resizing changes our own tqsizeHint(), because we must take the new PanelSize in account.
// So updateGeometry() is amust for us.
updateGeometry();
}
@@ -196,7 +196,7 @@ void ViewApplet::resizeEvent(TQResizeEvent *qre)
// kdDebug(67100) << "ViewApplet::resizeEvent(). SHOULD resize _layoutMDW to " << qre->size() << endl;
//TQWidget::resizeEvent(qre);
- // resizing changes our own tqsizeHint(), because we must take the new PanelSize in account.
+ // resizing changes our own sizeHint(), because we must take the new PanelSize in account.
// So updateGeometry() is amust for us.
updateGeometry();